netapp_ontap.models.firmware_update_progress API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_update_progress`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareUpdateProgressSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareUpdateProgress object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `job GET`

    The job field of the firmware_update_progress.

  `update_states GET`

    The update_states field of the firmware_update_progress.

  `zip_file_name GET`

    The zip_file_name field of the firmware_update_progress.

    Example: disk_firmware.zip